@@ -22,6 +22,7 @@
 #include "connectionmanager.h"
 #include "awaymanager.h"
 #include "transfermanager.h"
+#include "irccontextmenus.h"
 
 #include <QMenuBar>
 
@@ -46,6 +47,8 @@
 
 MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
 {
+    IrcContextMenus::setupUi(this);
+
     m_hasDirtySettings = false;
     m_closeApp = false;
     m_serverListDialog = nullptr;
@@ -818,16 +821,21 @@ void MainWindow::openKeyBindings()
     actionCollection()->action(QStringLiteral("open_logfile"))->setText(i18n("&Open Logfile"));
 
     // Open shortcut configuration dialog.
-    KShortcutsDialog::configure(actionCollection());
+    auto *dlg = new KShortcutsDialog(KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsAllowed, this);
+    dlg->setAttribute(Qt::WA_DeleteOnClose);
+    dlg->addCollection(actionCollection());
+    connect(dlg, &QDialog::finished, this, [this, openChannelListString, openLogFileString]() {
+        // Reset action names.
+        actionCollection()->action(QStringLiteral("tab_notifications"))->setText(i18n("Enable Notifications"));
+        actionCollection()->action(QStringLiteral("toggle_away"))->setText(i18n("Set &Away Globally"));
+        actionCollection()->action(QStringLiteral("irc_colors"))->setText(i18n("&IRC Color..."));
+        actionCollection()->action(QStringLiteral("insert_character"))->setText(i18n("Special &Character..."));
+        actionCollection()->action(QStringLiteral("insert_marker_line"))->setText(i18n("&Marker Line"));
+        actionCollection()->action(QStringLiteral("open_channel_list"))->setText(openChannelListString);
+        actionCollection()->action(QStringLiteral("open_logfile"))->setText(openLogFileString);
+    });
 
-    // Reset action names.
-    actionCollection()->action(QStringLiteral("tab_notifications"))->setText(i18n("Enable Notifications"));
-    actionCollection()->action(QStringLiteral("toggle_away"))->setText(i18n("Set &Away Globally"));
-    actionCollection()->action(QStringLiteral("irc_colors"))->setText(i18n("&IRC Color..."));
-    actionCollection()->action(QStringLiteral("insert_character"))->setText(i18n("Special &Character..."));
-    actionCollection()->action(QStringLiteral("insert_marker_line"))->setText(i18n("&Marker Line"));
-    actionCollection()->action(QStringLiteral("open_channel_list"))->setText(openChannelListString);
-    actionCollection()->action(QStringLiteral("open_logfile"))->setText(openLogFileString);
+    dlg->configure(true /* save settings */);
 }
 
 void MainWindow::openServerList()
