@@ -30,7 +30,6 @@
 #include "irccolorchooser.h"
 #include "joinchanneldialog.h"
 #include "servergroupsettings.h"
-#include "irccontextmenus.h"
 #include "viewtree.h"
 #include "viewspringloader.h"
 #include "konversation_log.h"
@@ -140,25 +139,12 @@ ViewContainer::ViewContainer(MainWindow* window) : QAbstractItemModel(window)
     m_dccPanel->hide();
     m_dccPanelOpen = false;
     connect(m_dccPanel, &DCC::TransferPanel::updateTabNotification, this, &ViewContainer::setViewNotification);
-
-    // Pre-construct context menus for better responsiveness when then
-    // user opens them the first time. This is optional; the IrcContext-
-    // Menus API would work fine without doing this here.
-    // IrcContextMenus' setup code calls Application::instance(), and
-    // ViewContainer is constructed in the scope of the Application
-    // constructor, so to avoid a crash we need to queue.
-    QMetaObject::invokeMethod(this, "setupIrcContextMenus", Qt::QueuedConnection);
 }
 
 ViewContainer::~ViewContainer()
 {
 }
 
-void ViewContainer::setupIrcContextMenus()
-{
-    IrcContextMenus::self();
-}
-
 void ViewContainer::showQueueTuner(bool p)
 {
     if (p)
